@@ -504,6 +504,8 @@ void SyncController::maindataAction()
     {
         const BitTorrent::CategoryOptions categoryOptions = session->categoryOptions(categoryName);
         QJsonObject category = categoryOptions.toJSON();
+        // adjust it to be compatible with exisitng WebAPI
+        category[QLatin1String("savePath")] = category.take(QLatin1String("save_path"));
         category.insert(QLatin1String("name"), categoryName);
         categories[categoryName] = category.toVariantMap();
     }
